Module elevation

Module elevation 

Elevation helpers for checking admin state and relaunching through UAC.

Functions

is_elevated
Returns true if the current process is running elevated.
restart_as_admin
Relaunches the current executable with elevation using the Windows runas shell verb.
run_as_admin
Launches an executable with elevation using the Windows runas shell verb.
run_with_verb
Launches an executable through ShellExecuteW using an explicit shell verb.