pub enum Error {
Unsupported(&'static str),
InvalidInput(&'static str),
PathNotAbsolute,
PathDoesNotExist,
Io(Error),
WindowsApi {
context: &'static str,
code: i32,
},
}Expand description
Error type for win-desktop-utils.
Examples
let err = win_desktop_utils::Error::InvalidInput("path cannot be empty");
assert_eq!(err.to_string(), "invalid input: path cannot be empty");Variants
Unsupported(&'static str)
The requested operation is not implemented on the current platform or in the current crate version.
InvalidInput(&'static str)
The caller supplied invalid input.
PathNotAbsolute
A path was required to be absolute but was not.
PathDoesNotExist
A required path does not exist.
Io(Error)
An underlying I/O operation failed.
WindowsApi
A Windows API call failed.