InstanceScope

Enum InstanceScope 

pub enum InstanceScope {
    CurrentSession,
    Global,
}
Scope used when creating the named mutex for single-instance enforcement.

Variants



CurrentSession

Use the current Windows session namespace (Local\...).



Global

Use the global Windows namespace (Global\...) so instances across all sessions contend for the same named mutex.