Module paths

Module paths 

Helpers for resolving and creating per-user application data directories.

Functions

ensure_local_app_data
Returns the local app-data directory for the given app name and creates it if needed.
ensure_roaming_app_data
Returns the roaming app-data directory for the given app name and creates it if needed.
local_app_data
Returns the per-user local app-data directory for the given app name.
roaming_app_data
Returns the per-user roaming app-data directory for the given app name.