Elevation helpers for checking admin state and relaunching through UAC.
Functions
- is_
elevated - Returns
trueif the current process is running elevated. - restart_
as_ admin - Relaunches the current executable with elevation using the Windows
runasshell verb. - run_
as_ admin - Launches an executable with elevation using the Windows
runasshell verb. - run_
with_ verb - Launches an executable through
ShellExecuteWusing an explicit shell verb.