Helpers for resolving and creating per-user application data directories.
Functions
- ensure_
local_ app_ data - Returns the local app-data directory for the given app name and creates it if needed.
- ensure_
roaming_ app_ data - Returns the roaming app-data directory for the given app name and creates it if needed.
- local_
app_ data - Returns the per-user local app-data directory for the given app name.
- roaming_
app_ data - Returns the per-user roaming app-data directory for the given app name.